#ifndef RODENT_GRIDVIEW_H
#define RODENT_GRIDVIEW_H

GtkWidget *
rodent_new_pathbar(void);

void 
rodent_new_gridview(widgets_t *widgets_p, const gchar *in_path);

int 
rodent_text_color(const population_t *population_p);

view_geometry_t *
rodent_get_view_geometry_p (view_t * view_p);

void
  rodent_save_root_view_geometry_p (view_t * view_p);

void
  rodent_save_local_view_geometry_p (view_t * view_p);

void
  rodent_set_scroll (view_t * view_p, double scroll_position);

void *
  rodent_set_scroll_position (gpointer data);

void
  rodent_apply_view_size (view_t * view_p);

gboolean 
rodent_set_upper_adjustment (view_t * view_p, int width, int height);

#endif
